#!/bin/sh
# Copyright (c) 2005 Andreas Mair
#
#
# Download and patchscript for VDRAdmin-AM
# (based on install.sh Copyright (c) 2003 Frank (xpix) Herrmann)

PATH=/sbin:/bin:/usr/sbin:/usr/bin
DESTDIR=/tmp
LIBDIR=$DESTDIR/usr/share/vdradmin
ETCDIR=$DESTDIR/etc/vdradmin
DOCDIR=$DESTDIR/usr/share/doc/vdradmin
BINDIR=$DESTDIR/usr/bin
LOCDIR=$DESTDIR/usr/share/locale
MANDIR=$DESTDIR/usr/share/man/man1
LOGDIR=$DESTDIR/var/log
PIDFILE=$DESTDIR/var/run/vdradmind.pid

LANGS="de es fr fi"

function usage()
{
	echo ""
	echo "usage: $(basename $0) [-c | -u | -p | -h]"
	echo ""
	echo -e "\t-c : Run \"vdradmind.pl -c\" after installation (=configure)."
	echo -e "\t-u : Perform uninstall."
	echo -e "\t-p : Only install needed Perl modules (NOT YET FINISHED!!!)."
	echo -e "\t-h : This message."
	echo ""
	exit 0
}

function perlModules()
{
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use Template' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"Template\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install Template'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use Compress::Zlib' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"Compress::Zlib\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install Compress::Zlib'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use CGI' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"CGI\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install CGI'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use IO::Socket' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"IO::Socket\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install IO::Socket'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use HTML::Entities' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"HTML::Entities\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install HTML::Entities'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use Time::Local' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"Time::Local\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install Time::Local'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use MIME::Base64' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"MIME::Base64\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install MIME::Base64'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use File::Temp' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"File::Temp\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install File::Temp'"
	perl -ce 'BEGIN{$0 =~ /(^.*\/)/; $BASENAME = $1; unshift(@INC, $BASENAME . "lib/");} use Locale::gettext' >/dev/null 2>&1
	[ $? -eq 2 ] && echo "You need \"Locale::gettext\"."
#	[ $? -eq 2 ] && su -c "perl -MCPAN -e 'install Locale::gettext'"
}

function doInstall()
{
	echo ""
	echo "********* Installing VDRAdmin-AM *************"
	echo ""

	perlModules

	[ ! -e $LIBDIR ] && mkdir -p $LIBDIR
	if [ -d $LIBDIR ]; then
  	cp -r template $LIBDIR
  	cp -r lib $LIBDIR
	else
		echo "$LIBDIR exists but is no directory!"
		echo "Aborting..."
		exit 1
	fi

	[ ! -e $DOCDIR ] && mkdir -p $DOCDIR
	if [ -d $DOCDIR ]; then
  	cp -r contrib COPYING HISTORY* INSTALL README* $DOCDIR
	else
		echo "$DOCDIR exists but is no directory!"
		echo "Aborting..."
		exit 1
	fi

	[ ! -e $MANDIR ] && mkdir -p $MANDIR
	if [ -d $MANDIR ]; then
		cp vdradmind.pl.1 $MANDIR
	else
		echo "$MANDIR exists but is no directory!"
		echo "Aborting..."
		exit 1
	fi

	[ ! -e $ETCDIR ] && mkdir -p $ETCDIR
	if [ ! -d $ETCDIR ]; then
		echo "$ETCDIR exists but is no directory!"
		echo "Aborting..."
		exit 1
	fi

	for lang in $LANGS
	do
		[ ! -e $LOCDIR/$lang/LC_MESSAGES/ ] && mkdir -p $LOCDIR/$lang/LC_MESSAGES/
	done

	local RESTART=
	[ ! -e $BINDIR ] && mkdir -p $BINDIR
	if [ -d $BINDIR ]; then
		if [ "$(pidof -x vdradmind.pl)" ] ; then
			RESTART=1
  		echo "Killing running VDRAdmin-AM..."
  		killall vdradmind.pl
  	fi
  	sed <vdradmind.pl >$BINDIR/vdradmind.pl \
  	    -e "s/^my \$SEARCH_FILES_IN_SYSTEM = 0;/my \$SEARCH_FILES_IN_SYSTEM = 1;/" \
  	    -e "s:/usr/share/vdradmin/lib:${LIBDIR}/lib:" \
  	    -e "s:/usr/share/vdradmin/template:${LIBDIR}/template:" \
  	    -e "s:/etc/vdradmin/vdradmind.conf:${ETCDIR}/vdradmind.conf:" \
  	    -e "s:/var/log/\$CONFIG{LOGFILE}:${LOGDIR}/\$CONFIG{LOGFILE}:" \
  	    -e "s:/var/run/vdradmind.pid:${PIDFILE}:" \
  	    -e "s:/etc/vdradmin/vdradmind.done:${ETCDIR}/vdradmind.done:" \
  	    -e "s:/etc/vdradmin/vdradmind.at:${ETCDIR}/vdradmind.at:" \
  	    -e "s:/etc/vdradmin/vdradmind.bl:${ETCDIR}/vdradmind.bl:" \
  	    -e "s:/usr/share/locale:${LOCDIR}:"

		chmod a+x  $BINDIR/vdradmind.pl

  	if [ "$CONFIG" ]; then
    	echo "Configuring VDRAdmin-AM..."
    	$BINDIR/vdradmind.pl -c
  	fi

  	if [ "$RESTART" ]; then
  		echo "Restarting VDRAdmin-AM..."
  		$BINDIR/vdradmind.pl
  	fi
	else
		echo "$BINDIR exists but is no directory!"
		echo "Aborting..."
		exit 1
	fi

	echo ""
	echo ""
	echo "VDRAdmin-AM has been installed!"
	echo ""
	if [ -z "$RESTART" ]; then
		echo "Run \"$BINDIR/vdradmind.pl\" to start VDRAdmin-AM."
		echo ""
	fi
	echo "NOTE:"
	echo "If you would like VDRAdmin-AM to start at system's boot, please modify your system's init scripts."
	exit 0
}

function doUninstall()
{
	echo ""
	echo "********* Uninstalling VDRAdmin-AM *************"
	echo ""

	if [ "$(pidof -x vdradmind.pl)" ]; then
		killall vdradmind.pl
	fi
	if [ -d $DOCDIR ]; then
		rm -rf $DOCDIR
	fi
	if [ -d $LIBDIR ]; then
		rm -rf $LIBDIR
	fi
	if [ -e $MANDIR/vdradmind.pl.1 ]; then
		rm -f $MANDIR/vdradmind.pl.1
	fi
	if [ -e $BINDIR/vdradmind.pl ]; then
		rm -f $BINDIR/vdradmind.pl
	fi
	for lang in $LANGS
	do
		[ -e $LOCDIR/$lang/LC_MESSAGES/vdradmin.mo ] && rm -f $LOCDIR/$lang/LC_MESSAGES/vdradmin.mo
	done

	echo ""
	echo "VDRAdmin-AM has been uninstalled!"
	echo ""
	if [ -d $ETCDIR ]; then
		echo "Your configuration files located in $ETCDIR have NOT been deleted!"
		echo "If you want to get rid of them, please delete them manually!"
		echo ""
	fi
}

UNINSTALL=
CONFIG=
PERL=
while [ "$1" ]
do
	case $1 in
		-u) UNINSTALL=1;;
		-c) CONFIG=1;;
		-p) PERL=1;;
		-h) usage;;
		*) echo "Ignoring param \"$1\$.";;
	esac
	shift
done

if [ $(basename $0) = "uninstall.sh" -o "$UNINSTALL" ]; then
	doUninstall
elif [ "$PERL" ]; then
	echo ""
	echo "Only LISTING needed Perl modules..."
	perlModules
	echo "...done."
else
	doInstall
fi
